@@ -50,8 +50,10 @@ public:
     LYWSD02,
     LYWSDCGQ,
     CGP1W,
-    CGG1_V1,
-    CGG1_V2,
+    CGG1_STOCK,
+    CGG1_ATC1441,
+    CGG1_PVVX,
+    CGG1_STOCK_2,
     CGDN1,
     CGD1,
     CGDK2,
@@ -91,10 +93,14 @@ public:
     GAEN,
     HHCCPOT002,
     BPARASITE,
+    BWBSDOO,
     BM2,
     RDL52832,
     ABN03,
     ABTEMP,
+    AMPHIRO,
+    TP35X,
+    T301,
     IBEACON,
     SERVICE_DATA,
     BLE_ID_MAX
@@ -113,7 +119,7 @@ private:
                                const char* dev_name, const char* svc_uuid);
   std::string sanitizeJsonKey(const char* key_in);
 
-  size_t m_docMax = 11000;
+  size_t m_docMax = 11500;
   size_t m_minSvcDataLen = 20;
   size_t m_minMfgDataLen = 16;
 };
