@@ -1,26 +1,26 @@
-const char* _HHCCJCY01HHCC_json = "{\"brand\":\"Xiaomi/VegTrug\",\"model\":\"MiFlora\",\"model_id\":\"HHCCJCY01HHCC\",\"condition\":[\"servicedata\",\"index\",2,\"209800\",\"|\",\"servicedata\",\"index\",2,\"20bc03\"],\"properties\":{\"tempc\":{\"condition\":[\"servicedata\",25,\"4\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,4,true],\"post_proc\":[\"/\",10]},\"moi\":{\"condition\":[\"servicedata\",25,\"8\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,2,false]},\"lux\":{\"condition\":[\"servicedata\",25,\"7\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,6,true]},\"fer\":{\"condition\":[\"servicedata\",25,\"9\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,4,true]}}}";
+const char* _HHCCJCY01HHCC_json = "{\"brand\":\"Xiaomi/VegTrug\",\"model\":\"MiFlora\",\"model_id\":\"HHCCJCY01HHCC\",\"condition\":[\"servicedata\",\"index\",4,\"9800\",\"|\",\"servicedata\",\"index\",4,\"bc03\",\"&\",\"uuid\",\"index\",0,\"fe95\"],\"properties\":{\"tempc\":{\"condition\":[\"servicedata\",24,\"0410\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,4,true],\"post_proc\":[\"/\",10]},\"moi\":{\"condition\":[\"servicedata\",24,\"0810\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,2,false]},\"lux\":{\"condition\":[\"servicedata\",24,\"0710\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,6,true]},\"fer\":{\"condition\":[\"servicedata\",24,\"0910\"],\"decoder\":[\"value_from_hex_data\",\"servicedata\",30,4,true]}}}";
 /*R""""(
 {
    "brand":"Xiaomi/VegTrug",
    "model":"MiFlora",
    "model_id":"HHCCJCY01HHCC",
-   "condition":["servicedata", "index", 2, "209800", "|", "servicedata", "index", 2, "20bc03"],
+   "condition":["servicedata", "index", 4, "9800", "|", "servicedata", "index", 4, "bc03", "&", "uuid", "index", 0, "fe95"],
    "properties":{
       "tempc":{
-         "condition":["servicedata", 25, "4"],
+         "condition":["servicedata", 24, "0410"],
          "decoder":["value_from_hex_data", "servicedata", 30, 4, true],
          "post_proc":["/", 10]
       },
       "moi":{
-         "condition":["servicedata", 25, "8"],
+         "condition":["servicedata", 24, "0810"],
          "decoder":["value_from_hex_data", "servicedata", 30, 2, false]
       },
       "lux":{
-         "condition":["servicedata", 25, "7"],
+         "condition":["servicedata", 24, "0710"],
          "decoder":["value_from_hex_data", "servicedata", 30, 6, true]
       },
       "fer":{
-         "condition":["servicedata", 25, "9"],
+         "condition":["servicedata", 24, "0910"],
          "decoder":["value_from_hex_data", "servicedata", 30, 4, true]
       }
    }
@@ -47,4 +47,4 @@ const char* _HHCCJCY01HHCC_json_props = "{\"properties\":{\"lux\":{\"unit\":\"lx
          "name":"moisture"
       }
    }
-})"""";*/
\ No newline at end of file
+})"""";*/
